@@ -347,7 +347,7 @@ class Study(object):
         self.logger.info(self.ensemble.clf.show_models())
         test_res = self.ensemble.predict(self.storage.X_test)
         metrics_func = self._get_metric(self.metrics)
-        metrics_func = self._get_metric('acc')
+        # metrics_func = self._get_metric('acc')
         result = metrics_func(self.storage.y_test, test_res)
         self.logger.info("The ensemble of all trials get the result: {0}   {1}".format(self.metrics, result))
 
@@ -452,7 +452,6 @@ class Study(object):
         # tpot耗时较久，舍弃。相同时间内不如auto-sklearn
         auto_sklearn_trial = self.generate_trial(mode='fast', n_jobs=n_jobs, include_estimators=[
                                                  "extra_trees", "random_forest", "gaussian_nb"])
-        # tpot_trial = self.generate_tpot_trial()
         return [auto_sklearn_trial]
 
     def _optimize_sequential(
@@ -640,7 +639,7 @@ class Study(object):
         trial.clf = autosk_clf
         return trial
 
-    def generate_trial(self, mode='fast', n_jobs=-1, time_left_for_this_task=3600, per_run_time_limit=360,
+    def generate_trial(self, mode='fast', n_jobs=-1, time_left_for_this_task=3600, per_run_time_limit=360,memory_limit=8192,
                        initial_configurations_via_metalearning=25, ensemble_size=50, ensemble_nbest=50,
                         seed=1,include_estimators=['random_forest', 'LogisticRegressionSK', 'LogisticRegressionSMAC'],
                        exclude_estimators=None, include_preprocessors=None, exclude_preprocessors=None,
@@ -676,12 +675,13 @@ class Study(object):
         if mode == 'fast':
             time_left_for_this_task = 120
             per_run_time_limit = 30
+            memory_limit = 4096
             ensemble_size = 5
             ensemble_nbest = 2
         elif mode == 'big':
             ensemble_size = 50
             ensemble_nbest = 20
-            # ml_memory_limit = 10240
+            memory_limit = 10240
             # ensemble_memory_limit = 4096
             time_left_for_this_task = 14400
             per_run_time_limit = 1440
@@ -717,7 +717,7 @@ class Study(object):
                     "ensemble_nbest": ensemble_nbest,
                     # "ensemble_memory_limit": ensemble_memory_limit,
                     "seed": seed,
-                    # "ml_memory_limit": ml_memory_limit,
+                    "memory_limit": memory_limit,
                     "include_estimators": include_estimators,
                     "exclude_estimators": exclude_estimators,
                     "include_preprocessors": include_preprocessors,
@@ -739,24 +739,6 @@ class Study(object):
         self.trial_list.append(auto_sklearn_trial)
         return auto_sklearn_trial
 
-    # def generate_tpot_trial(self, mode='fast', **kwargs):
-    #     tpot_trial = create_trial(self)
-    #     # ref: http://epistasislab.github.io/tpot/api/
-    #     # TPOT will evaluate population_size + generations × offspring_size pipelines in total.
-    #     if mode == 'fast':
-    #         tpot_clf = TPOTClassifier(generations=5, population_size=10,
-    #                                   verbosity=2, n_jobs=-1, max_eval_time_mins=10, early_stop=5)
-    #     elif mode == 'test':
-    #         tpot_clf = TPOTClassifier(
-    #             generations=2, population_size=10, n_jobs=-1, verbosity=1)
-    #     elif mode == 'self-define':
-    #         tpot_clf = TPOTClassifier(**kwargs)
-    #     else:
-    #         tpot_clf = TPOTClassifier(generations=50, population_size=100,
-    #                                   verbosity=2, scoring='accuracy', n_jobs=-1, max_eval_time_mins=60, early_stop=30)
-    #     tpot_trial.clf = tpot_clf
-    #     self.trial_list.append(tpot_trial)
-    #     return tpot_trial
 
     def add_preprocessor_trial(self, trial):
         pass
